@@ -1,9 +1,9 @@
-"""Version information for pynetdicom based on PEP396 and 440."""
+"""Version information for pylibjpeg based on PEP396 and 440."""
 
 import re
 
 
-__version__ = '1.2.0'
+__version__ = "1.4.0"
 
 
 VERSION_PATTERN = r"""
@@ -41,11 +41,13 @@ VERSION_PATTERN = r"""
 def is_canonical(version):
     """Return True if `version` is a PEP440 conformant version."""
     match = re.match(
-        r'^([1-9]\d*!)?(0|[1-9]\d*)'
-        r'(\.(0|[1-9]\d*))'
-        r'*((a|b|rc)(0|[1-9]\d*))'
-        r'?(\.post(0|[1-9]\d*))'
-        r'?(\.dev(0|[1-9]\d*))?$', version)
+        r"^([1-9]\d*!)?(0|[1-9]\d*)"
+        r"(\.(0|[1-9]\d*))"
+        r"*((a|b|rc)(0|[1-9]\d*))"
+        r"?(\.post(0|[1-9]\d*))"
+        r"?(\.dev(0|[1-9]\d*))?$",
+        version,
+    )
 
     return match is not None
 
