@@ -1,4 +1,3 @@
-
 import logging
 import sys
 
@@ -6,9 +5,10 @@ _logger = logging.getLogger(__name__)
 
 try:
     import ljdata as _data
-    globals()['data'] = _data
+
+    globals()["data"] = _data
     # Add to cache - needed for pytest
-    sys.modules['pylibjpeg.data'] = _data
-    _logger.debug('pylibjpeg-data module loaded')
+    sys.modules["pylibjpeg.data"] = _data
+    _logger.debug("pylibjpeg-data module loaded")
 except ImportError:
     pass
